/*
 * The MIT License (MIT)
 * Copyright (c) 2013 Mark Paluch
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is furnished
 * to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
 * INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
 * PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

package biz.paluch.maven.configurator;

import org.apache.maven.plugin.MojoExecutionException;
import org.apache.maven.plugin.MojoFailureException;
import org.apache.maven.plugins.annotations.Execute;
import org.apache.maven.plugins.annotations.LifecyclePhase;
import org.apache.maven.plugins.annotations.Mojo;

import java.io.File;

/**
 * Perform configuration for the project artifact.
 * @author <a href="mailto:mpaluch@paluch.biz">Mark Paluch</a>
 */
@Mojo(name = "configure")
@Execute(phase = LifecyclePhase.PACKAGE)
public class ConfigureMojo extends AbstractConfigureMojo {

    /**
     * Perform configuration for the project artifact.
     *
     * @throws org.apache.maven.plugin.MojoExecutionException
     * @throws org.apache.maven.plugin.MojoFailureException
     */
    @Override
    public void execute() throws MojoExecutionException, MojoFailureException {


        PackageType packageType = resolvePackageType(project.getPackaging());

        String fileName = project.getBuild().getFinalName() + "." + packageType.getFileExtension();
        configure(new File(targetDir, fileName));
    }

    private PackageType resolvePackageType(String packaging) throws MojoExecutionException {


        for (PackageType packagingType : PackageType.values()) {
            if (packagingType.getPackaging().equalsIgnoreCase(packaging)) {
                return packagingType;
            }
        }
        throw new MojoExecutionException("Cannot process packaging type " + packaging);
    }

}
