/*
 * The MIT License (MIT)
 * Copyright (c) 2013 Mark Paluch
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is furnished
 * to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
 * INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
 * PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

package biz.paluch.maven.configurator;

import java.io.IOException;
import java.io.InputStream;

/**
 * Limited and Non-Closing InputStream.
 * @author <a href="mailto:mpaluch@paluch.biz">Mark Paluch</a>
 * @since 08.04.13 12:43
 */
public class LimitedNonClosingInputStream extends InputStream {

    private long position = 0;
    private long limit = 0;

    private InputStream parent;

    public LimitedNonClosingInputStream(long limit, InputStream parent) {
        this.limit = limit;
        this.parent = parent;
    }

    @Override
    public int available() throws IOException {

        long result = limit - position;
        return (int) result;
    }

    @Override
    public int read() throws IOException {
        position++;
        return parent.read();
    }

    @Override
    public int read(byte[] b) throws IOException {
        int read = parent.read(b);
        position += read;
        return read;
    }

    @Override
    public int read(byte[] b, int off, int len) throws IOException {
        int read = parent.read(b, off, len);
        position += read;
        return read;
    }

    @Override
    public long skip(long n) throws IOException {
        long skipped = super.skip(n);
        position += skipped;
        return skipped;
    }

    @Override
    public void close() throws IOException {
    }
}
